@@ -1,14 +1,14 @@
 #include <stdlib.h>
+#include <string.h>
 #include "relay-ctrl.h"
 
 int is_authenticated(void)
 {
   if (getenv("AUTHUSER") && getenv("AUTHARGV0")) {
     /* Courier IMAP or POP3 */
-    if (getenv("AUTHENTICATED"))
-      return 1;
+    char *authenticated = getenv("AUTHENTICATED");
+    return authenticated != 0 && *authenticated != 0;
   }
   else
     return 1;
-  return 0;
 }
