@@ -4,11 +4,11 @@
 #include <stdlib.h>
 #include <string.h>
 #include <sys/stat.h>
-#include "systime.h"
+#include <bglibs/systime.h>
 #include <unistd.h>
 #include <utime.h>
-#include "misc/misc.h"
-#include "msg/msg.h"
+#include <bglibs/misc.h>
+#include <bglibs/msg.h>
 #include "relay-ctrl.h"
 
 const char program[] = "relay-ctrl-allow";
@@ -30,17 +30,16 @@ static int write_env(int fd, const char* var)
   return 1;
 }
 
-static void make_file(const char* filename)
+static void make_file(const char* filename, int save_cwd)
 {
   int fd;
-  int error;
   int saved_umask;
   int mode;
-  char tmpfile[256];
+  char tmpname[256];
   char* ptr;
   struct timeval t;
   
-  switch (do_chdir()) {
+  switch (do_chdir(save_cwd)) {
   case 0: return;
   case 2: mode = 0666; break;
   default: mode = 0600; break;
@@ -48,27 +47,28 @@ static void make_file(const char* filename)
   saved_umask = umask(0);
 
   gettimeofday(&t, 0);
-  ptr = tmpfile; *ptr++ = '.';
+  ptr = tmpname; *ptr++ = '.';
   ptr = utoa2(t.tv_sec, ptr); *ptr++ = '.';
   ptr = utoa2(t.tv_usec, ptr); *ptr++ = ':';
   ptr = utoa2(getpid(), ptr);
   
-  if ((fd = open(tmpfile, O_WRONLY|O_CREAT|O_EXCL, mode)) == -1)
-    warn3sys("Could not open '", tmpfile, "' for writing");
+  if ((fd = open(tmpname, O_WRONLY|O_CREAT|O_EXCL, mode)) == -1)
+    warn3sys("Could not open '", tmpname, "' for writing");
   else {
-    error = 0;
     if (!write_env(fd, "USER") ||
 	!write_env(fd, "DOMAIN") ||
 	close(fd) == -1) {
       warn3sys("Could not write to '", filename, "'");
       close(fd);
     }
-    else if (rename(tmpfile, filename) == -1)
-      warn5sys("Could not rename '", tmpfile, "' to '", filename, "'");
-    unlink(tmpfile);
+    else if (rename(tmpname, filename) == -1)
+      warn5sys("Could not rename '", tmpname, "' to '", filename, "'");
+    unlink(tmpname);
+  }
+  if (save_cwd) {
+    umask(saved_umask);
+    do_chdir_back();
   }
-  umask(saved_umask);
-  do_chdir_back();
 }
 
 int main(int argc, char* argv[])
@@ -79,7 +79,7 @@ int main(int argc, char* argv[])
     warn1("$RELAY_CTRL_DIR is not set.");
   else
     if (is_authenticated())
-      make_file(ip);
+      make_file(ip, argc > 1);
 
   if (argc > 1) {
     execvp(argv[1], argv+1);
